# PyXIRR

Rust-powered collection of financial functions.

# Table of Contents

* [Installation](install.md)
* [Functions](functions.md)
    * [Type annotations](functions.md#type-annotations)
    * [Exceptions](functions.md#exceptions)
    * [FV](functions.md#fv)
    * [XFV](functions.md#xfv)
    * [PMT](functions.md#pmt)
    * [NPER](functions.md#nper)
    * [PV](functions.md#pv)
    * [NPV](functions.md#npv)
    * [XNPV](functions.md#xnpv)
    * [IRR](functions.md#irr)
    * [MIRR](functions.md#mirr)
    * [XIRR](functions.md#xirr)
* [Benchmarks](bench/index.html)
